==> abp.aspnetcore.mvc.ui.theme.front-0.0.3.tgz: package/Themes/Front/Components/Public/Header/Navbar/PublicHeaderNavbarViewComponent.cs <==
﻿using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Ravco.Abp.AspNetCore.Mvc.UI.Theme.Front.Navigations;
using Volo.Abp.AspNetCore.Mvc.UI.Layout;
using Volo.Abp.UI.Navigation;

namespace Ravco.Abp.AspNetCore.Mvc.UI.Theme.Front.Themes.Front.Components.Public.Header.Navbar;

public class PublicHeaderNavbarViewComponent : FrontViewComponentBase
{
    protected IMenuManager MenuManager { get; }
    protected IPageLayout PageLayout { get; }

    public PublicHeaderNavbarViewComponent(IMenuManager menuManager, IPageLayout pageLayout)
    {
        MenuManager = menuManager;
        PageLayout = pageLayout;
    }

    public virtual async Task<IViewComponentResult> InvokeAsync()
    {
        var menu = await MenuManager.GetAsync(FrontMenus.Public.Main);
        var viewModel = ObjectMapper.Map<ApplicationMenu, MenuViewModel>(menu);

        if (!PageLayout.Content.MenuItemName.IsNullOrEmpty())
        {
            SetActiveMenuItems(viewModel.Items, PageLayout.Content.MenuItemName);
        }

        return View(
            "~/Themes/Front/Components/Public/Header/Navbar/Default.cshtml",
            viewModel
        );
    }

    protected virtual bool SetActiveMenuItems(IList<MenuItemViewModel> items, string activeMenuItemName)
    {
        foreach (var item in items)
        {
            if (item.MenuItem.Name == activeMenuItemName ||
                SetActiveMenuItems(item.Items, activeMenuItemName))
            {
                item.IsActive = true;
                return true;
            }
        }

        return false;
    }
}

==> abp.aspnetcore.mvc.ui.theme.front-0.0.4.tgz: package/Themes/Front/Components/Public/Header/Navbar/PublicHeaderNavbarViewComponent.cs <==
﻿using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Ravco.Abp.AspNetCore.Mvc.UI.Theme.Front.Navigations;
using Volo.Abp.AspNetCore.Mvc.UI.Layout;
using Volo.Abp.UI.Navigation;

namespace Ravco.Abp.AspNetCore.Mvc.UI.Theme.Front.Themes.Front.Components.Public.Header.Navbar;

public class PublicHeaderNavbarViewComponent : FrontViewComponentBase
{
    protected IMenuManager MenuManager { get; }
    protected IPageLayout PageLayout { get; }

    public PublicHeaderNavbarViewComponent(IMenuManager menuManager, IPageLayout pageLayout)
    {
        MenuManager = menuManager;
        PageLayout = pageLayout;
    }

    public virtual async Task<IViewComponentResult> InvokeAsync()
    {
        var menu = await MenuManager.GetAsync(FrontMenus.Public.Header);
        var viewModel = ObjectMapper.Map<ApplicationMenu, MenuViewModel>(menu);

        if (!PageLayout.Content.MenuItemName.IsNullOrEmpty())
        {
            SetActiveMenuItems(viewModel.Items, PageLayout.Content.MenuItemName);
        }

        return View(
            "~/Themes/Front/Components/Public/Header/Navbar/Default.cshtml",
            viewModel
        );
    }

    protected virtual bool SetActiveMenuItems(IList<MenuItemViewModel> items, string activeMenuItemName)
    {
        foreach (var item in items)
        {
            if (item.MenuItem.Name == activeMenuItemName ||
                SetActiveMenuItems(item.Items, activeMenuItemName))
            {
                item.IsActive = true;
                return true;
            }
        }

        return false;
    }
}
